﻿### EXECUTE BELOW BEFORE ANYTHING ELSE ###

#Loads SharePoint PowerShell Snapin
Add-PSSnapin Microsoft.SharePoint.PowerShell -ErrorAction "SilentlyContinue" | Out-Null

# set global variables used by subsequent commands
$databaseServerName = "SQL01"				#Database Server
$appPoolUserName = "pdd\spservice"  		#App pool identity
$saAppPoolName = "SharePoint Services Apps"	#App pool name
$FarmName = "Farm1" 						#Database Prefix

# Check to see if app pool already exists, if not create it
$saAppPool = Get-SPServiceApplicationPool -Identity $saAppPoolName -EA 0  
if($saAppPool -eq $null)  
{  
   Write-Host "Creating Service Application Pool..." 

   # Check to see if identity is already a SP managed account
   # if not, create it as a managed account
   $appPoolAccount = Get-SPManagedAccount -Identity $appPoolUserName -EA 0  
   if($appPoolAccount -eq $null)  
   {  
       Write-Host "Please supply the password for the Service Account..." 
       $appPoolCred = Get-Credential $appPoolUserName  
       $appPoolAccount = New-SPManagedAccount -Credential $appPoolCred -EA 0  
   }  

   $appPoolAccount = Get-SPManagedAccount -Identity $appPoolUserName -EA 0  

   # Create the app pool
   New-SPServiceApplicationPool -Name $saAppPoolName -Account $appPoolAccount -EA 0 > $null  
   $saAppPool = Get-SPServiceApplicationPool -Identity $saAppPoolName -EA 0
   
   if($saAppPool -eq $null)  
   { write-host "ERROR: Could not create app pool" }
   else { Write-Host "App Pool Created Sucessfully" }
}
### END PRE-REQS ###



### Site Subscription Service ###
$subsInstanceName = "SPSubscriptionSettingsServiceInstance"
$subsName = "Hosting Subscription Settings"
$subsDBName = "Hosting_SubscriptionSettings"
Write-Host "Creating $subsName Application and Proxy..."
$subs = New-SPSubscriptionSettingsServiceApplication –ApplicationPool $saAppPool –Name $subsName –DatabaseName $subsDBName
$proxy = New-SPSubscriptionSettingsServiceApplicationProxy –ServiceApplication $subs
Write-Host "Starting subsInstanceName..."
Get-SPServiceInstance | where{$_.GetType().Name -eq $subsInstanceName} | Start-SPServiceInstance
